@@ -6,6 +6,8 @@ import pika
 import tornado.ioloop
 import tornado.web
 
+from hurricane.kubernetes import K8sServerMetricsHandler
+
 logging.basicConfig(level=logging.INFO)
 
 
@@ -64,3 +66,12 @@ class WebhookReceiverServer:
                 ("/webhook", WebhookTestHandler),
             ]
         )
+
+
+class K8sServer:
+    def make_http_receiver_app(self):
+        return tornado.web.Application(
+            [
+                ("/k8s", K8sServerMetricsHandler),
+            ]
+        )
